==> jc-1.4.0.tar.gz: java/security/VMAccessController.h <==
// final class java.security.VMAccessController

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a0b5b25c3d44fe32 java_security_VMAccessController

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_VMAccessController_H_
#define _JC_java_security_VMAccessController_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_ThreadLocal$object;
struct _jc_java_security_AccessControlContext$object;

// Typedefs
typedef struct _jc_java_security_VMAccessController$sub_refs	_jc_java_security_VMAccessController$sub_refs;
typedef struct _jc_java_security_VMAccessController$sub_nonrefs	_jc_java_security_VMAccessController$sub_nonrefs;
typedef struct _jc_java_security_VMAccessController$refs	_jc_java_security_VMAccessController$refs;
typedef struct _jc_java_security_VMAccessController$nonrefs	_jc_java_security_VMAccessController$nonrefs;
typedef struct _jc_java_security_VMAccessController$object	_jc_java_security_VMAccessController$object;

typedef struct _jc_java_security_VMAccessController$fields_struct	_jc_java_security_VMAccessController$fields_struct;
typedef const struct _jc_java_security_VMAccessController$vmethods	_jc_java_security_VMAccessController$vmethods;
typedef const struct _jc_java_security_VMAccessController$vtable	_jc_java_security_VMAccessController$vtable;
typedef const struct _jc_java_security_VMAccessController$vtype	_jc_java_security_VMAccessController$vtype;

// Class fields structure
struct _jc_java_security_VMAccessController$fields_struct {
	struct _jc_java_security_AccessControlContext$object	*DEFAULT__5fCONTEXT;
	struct _jc_java_lang_Class$object	*class__24java__24security__24AccessController;
	struct _jc_java_lang_ThreadLocal$object	*contexts;
	struct _jc_java_lang_ThreadLocal$object	*inGetContext;
	jboolean	DEBUG;
};
extern _jc_java_security_VMAccessController$fields_struct _jc_java_security_VMAccessController$class_fields;

// Constructors
extern void _jc_java_security_VMAccessController$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_VMAccessController$object *);

// Static methods
extern void _jc_java_security_VMAccessController$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_java_security_VMAccessController$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_java_security_VMAccessController$method$debug$1e3312c3736b0b51(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_security_AccessControlContext$object *_jc_java_security_VMAccessController$method$getContext$ed3d42e32d89c9e4(_jc_env *);
extern _jc_object_array *_jc_java_security_VMAccessController$method$getStack$7fe225701efbffe3(_jc_env *);
extern void _jc_java_security_VMAccessController$method$popContext$22a28106f09f995b(_jc_env *);
extern void _jc_java_security_VMAccessController$method$pushContext$a0b89666ea22e118(_jc_env *, struct _jc_java_security_AccessControlContext$object *);

// Virtual methods structure
struct _jc_java_security_VMAccessController$vmethods {
};

// Vtable
struct _jc_java_security_VMAccessController$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_VMAccessController$vmethods	java_security_VMAccessController;
};

// Vtype
struct _jc_java_security_VMAccessController$vtype {
	_jc_type			type;
	_jc_java_security_VMAccessController$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_VMAccessController$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_VMAccessController$refs {
    _jc_java_security_VMAccessController$sub_refs	java_security_VMAccessController;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_VMAccessController$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_VMAccessController$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_VMAccessController$sub_nonrefs	java_security_VMAccessController;
};

// Object instance structure
struct _jc_java_security_VMAccessController$object {
	_jc_java_security_VMAccessController$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_VMAccessController$vtype	*vtype;
	_jc_java_security_VMAccessController$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_VMAccessController$vtype _jc_java_security_VMAccessController$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_VMAccessController, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_VMAccessController$class_object;

#endif	/* _JC_java_security_VMAccessController_H_ */

==> jc-1.4.6.tar.gz: java/security/VMAccessController.h <==
// final class java.security.VMAccessController

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a0b5b25c3d44fe32 java_security_VMAccessController

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_VMAccessController_H_
#define _JC_java_security_VMAccessController_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_ThreadLocal$object;
struct _jc_java_security_AccessControlContext$object;

// Typedefs
typedef struct _jc_java_security_VMAccessController$sub_refs	_jc_java_security_VMAccessController$sub_refs;
typedef struct _jc_java_security_VMAccessController$sub_nonrefs	_jc_java_security_VMAccessController$sub_nonrefs;
typedef struct _jc_java_security_VMAccessController$refs	_jc_java_security_VMAccessController$refs;
typedef struct _jc_java_security_VMAccessController$nonrefs	_jc_java_security_VMAccessController$nonrefs;
typedef struct _jc_java_security_VMAccessController$object	_jc_java_security_VMAccessController$object;

typedef struct _jc_java_security_VMAccessController$fields_struct	_jc_java_security_VMAccessController$fields_struct;
typedef const struct _jc_java_security_VMAccessController$vmethods	_jc_java_security_VMAccessController$vmethods;
typedef const struct _jc_java_security_VMAccessController$vtable	_jc_java_security_VMAccessController$vtable;
typedef const struct _jc_java_security_VMAccessController$vtype	_jc_java_security_VMAccessController$vtype;

// Class fields structure
struct _jc_java_security_VMAccessController$fields_struct {
	struct _jc_java_security_AccessControlContext$object	*DEFAULT__5fCONTEXT;
	struct _jc_java_lang_Class$object	*class__24java__24security__24AccessController;
	struct _jc_java_lang_ThreadLocal$object	*contexts;
	struct _jc_java_lang_ThreadLocal$object	*inGetContext;
	jboolean	DEBUG;
};
extern _jc_java_security_VMAccessController$fields_struct _jc_java_security_VMAccessController$class_fields;

// Constructors
extern void _jc_java_security_VMAccessController$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_VMAccessController$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_security_VMAccessController$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_security_VMAccessController$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_security_VMAccessController$method$debug$1e3312c3736b0b51(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_AccessControlContext$object *_jc_java_security_VMAccessController$method$getContext$ed3d42e32d89c9e4(_jc_env *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_security_VMAccessController$method$getStack$7fe225701efbffe3(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_security_VMAccessController$method$popContext$22a28106f09f995b(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_security_VMAccessController$method$pushContext$a0b89666ea22e118(_jc_env *, struct _jc_java_security_AccessControlContext$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_VMAccessController$vmethods {
};

// Vtable
struct _jc_java_security_VMAccessController$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_VMAccessController$vmethods	java_security_VMAccessController;
};

// Vtype
struct _jc_java_security_VMAccessController$vtype {
	_jc_type			type;
	_jc_java_security_VMAccessController$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_VMAccessController$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_VMAccessController$refs {
    _jc_java_security_VMAccessController$sub_refs	java_security_VMAccessController;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_VMAccessController$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_VMAccessController$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_VMAccessController$sub_nonrefs	java_security_VMAccessController;
};

// Object instance structure
struct _jc_java_security_VMAccessController$object {
	_jc_java_security_VMAccessController$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_VMAccessController$vtype	*vtype;
	_jc_java_security_VMAccessController$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_VMAccessController$vtype _jc_java_security_VMAccessController$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_VMAccessController, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_VMAccessController$class_object;

#endif	/* _JC_java_security_VMAccessController_H_ */
